pub struct AlgorithmIdentifier<Params> {
pub oid: ObjectIdentifier,
pub parameters: Option<Params>,
}pkcs8 only.Expand description
X.509 AlgorithmIdentifier as defined in RFC 5280 Section 4.1.1.2.
AlgorithmIdentifier ::= SEQUENCE {
algorithm OBJECT IDENTIFIER,
parameters ANY DEFINED BY algorithm OPTIONAL }Fields
oid: ObjectIdentifierAlgorithm OID, i.e. the algorithm field in the AlgorithmIdentifier
ASN.1 schema.
parameters: Option<Params>Algorithm parameters.
Implementations
Sourceimpl<Params> AlgorithmIdentifier<Params>
impl<Params> AlgorithmIdentifier<Params>
Sourcepub fn assert_algorithm_oid(
&self,
expected_oid: ObjectIdentifier,
) -> Result<ObjectIdentifier, Error>
pub fn assert_algorithm_oid( &self, expected_oid: ObjectIdentifier, ) -> Result<ObjectIdentifier, Error>
Assert the algorithm OID is an expected value.
Errors
Returns Error::OidUnknown if self does not match expected_oid.
Sourceimpl<'a> AlgorithmIdentifier<AnyRef<'a>>
impl<'a> AlgorithmIdentifier<AnyRef<'a>>
Sourcepub fn assert_parameters_oid(
&self,
expected_oid: ObjectIdentifier,
) -> Result<ObjectIdentifier, Error>
pub fn assert_parameters_oid( &self, expected_oid: ObjectIdentifier, ) -> Result<ObjectIdentifier, Error>
Assert parameters is an OID and has the expected value.
Errors
Returns Error::OidUnknown if self.parameters_oid() doesn’t match expected_oid.
Sourcepub fn assert_oids(
&self,
algorithm: ObjectIdentifier,
parameters: ObjectIdentifier,
) -> Result<(), Error>
pub fn assert_oids( &self, algorithm: ObjectIdentifier, parameters: ObjectIdentifier, ) -> Result<(), Error>
Assert the values of the algorithm and parameters OIDs.
Errors
Returns Error::OidUnknown if algorithm and/or parameters aren’t the expected values.
Sourcepub fn parameters_any(&self) -> Result<AnyRef<'a>, Error>
pub fn parameters_any(&self) -> Result<AnyRef<'a>, Error>
Get the parameters field as an AnyRef.
Errors
Returns Error::AlgorithmParametersMissing error if self.parameters are None.
Sourcepub fn parameters_oid(&self) -> Result<ObjectIdentifier, Error>
pub fn parameters_oid(&self) -> Result<ObjectIdentifier, Error>
Get the parameters field as an ObjectIdentifier.
Errors
- Returns
Error::AlgorithmParametersMissingerror ifself.parametersareNone. - Returns
Error::Asn1ifself.parametersis not an OID.
Sourcepub fn oids(
&self,
) -> Result<(ObjectIdentifier, Option<ObjectIdentifier>), Error>
pub fn oids( &self, ) -> Result<(ObjectIdentifier, Option<ObjectIdentifier>), Error>
Convert to a pair of ObjectIdentifiers.
This method is helpful for decomposing in match statements. Note in
particular that NULL parameters are treated the same as missing
parameters.
Errors
Returns an error if parameters are present but not an OID.