pub struct SecretDocument(/* private fields */);Available on crate features
pkcs8 and zeroize only.Expand description
Secret Document type.
Useful for formats which represent potentially secret data, such as cryptographic keys.
This type provides additional hardening such as ensuring that the contents are zeroized-on-drop, and also using more restrictive file permissions when writing files to disk.
Implementations
Sourceimpl SecretDocument
impl SecretDocument
Sourcepub fn to_bytes(&self) -> Zeroizing<Vec<u8>>
pub fn to_bytes(&self) -> Zeroizing<Vec<u8>>
Return an allocated ASN.1 DER serialization as a byte vector.
Sourcepub fn decode_msg<'a, T>(&'a self) -> Result<T, <T as Decode<'a>>::Error>where
T: Decode<'a>,
pub fn decode_msg<'a, T>(&'a self) -> Result<T, <T as Decode<'a>>::Error>where
T: Decode<'a>,
Try to decode the inner ASN.1 DER message as the given type.
Errors
Returns T::Error if a decoding error occurred.
Sourcepub fn encode_msg<T>(msg: &T) -> Result<SecretDocument, Error>where
T: Encode,
pub fn encode_msg<T>(msg: &T) -> Result<SecretDocument, Error>where
T: Encode,