DecodePublicKey

Trait DecodePublicKey 

pub trait DecodePublicKey: Sized {
    // Required method
    fn from_public_key_der(bytes: &[u8]) -> Result<Self, Error>;
}
Available on crate feature pkcs8 only.
Parse a public key object from an encoded SPKI document.

Required Methods

fn from_public_key_der(bytes: &[u8]) -> Result<Self, Error>

Deserialize object from ASN.1 DER-encoded [SubjectPublicKeyInfo] (binary format).

Errors

Returns decoding errors specific to the concrete type which impls this trait.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> DecodePublicKey for T
where T: for<'a> TryFrom<SubjectPublicKeyInfo<AnyRef<'a>, BitStringRef<'a>>, Error = Error>,