ExpandedSigningKey

Struct ExpandedSigningKey 

pub struct ExpandedSigningKey<P: MlDsaParams> { /* private fields */ }
An ML-DSA signing key

Implementations

Source

impl<P: MlDsaParams> ExpandedSigningKey<P>

pub fn from_seed(seed: &Seed) -> Self

Deterministically generate an expanded signing key from the specified seed.

This method reflects the ML-DSA.KeyGen_internal algorithm from FIPS 204, but only returns a signing key.

pub fn sign_internal(&self, Mp: &[&[u8]], rnd: &B32) -> Signature<P>
where P: MlDsaParams,

This method reflects the ML-DSA.Sign_internal algorithm from FIPS 204. It does not include the domain separator that distinguishes between the normal and pre-hashed cases, and it does not separate the context string from the rest of the message.

pub fn sign_randomized<R: TryCryptoRng + ?Sized>( &self, M: &[u8], ctx: &[u8], rng: &mut R, ) -> Result<Signature<P>, Error>

Available on crate feature rand_core only.

This method reflects the randomized ML-DSA.Sign algorithm.

Errors

This method will return an opaque error if the context string is more than 255 bytes long, or if it fails to get enough randomness.

pub fn sign_mu_randomized<R: TryCryptoRng + ?Sized>( &self, mu: &Array<u8, U64>, rng: &mut R, ) -> Result<Signature<P>, Error>

Available on crate feature rand_core only.

This method reflects the randomized ML-DSA.Sign algorithm with a pre-computed μ.

Errors

This method can return an opaque error if it fails to get enough randomness.

pub fn sign_deterministic( &self, M: &[u8], ctx: &[u8], ) -> Result<Signature<P>, Error>

This method reflects the optional deterministic variant of the ML-DSA.Sign algorithm.

Errors

This method will return an opaque error if the context string is more than 255 bytes long.

pub fn sign_mu_deterministic(&self, mu: &Array<u8, U64>) -> Signature<P>

This method reflects the optional deterministic variant of the ML-DSA.Sign algorithm with a pre-computed μ.

pub fn verifying_key(&self) -> VerifyingKey<P>

This auxiliary function derives a VerifyingKey from a bare ExpandedSigningKey (even in the absence of the original seed).

This is a utility function that is useful when importing the private key from an external source which does not export the seed and does not provide the precomputed public key associated with the private key itself.

ExpandedSigningKey implements signature::Keypair: this inherent method is retained for convenience, so it is available for callers even when the signature::Keypair trait is out-of-scope.

pub fn from_expanded(enc: &ExpandedSigningKeyBytes<P>) -> Self
where P: MlDsaParams,

👎Deprecated since 0.1.0:

use ExpandedSigningKey::from_seed instead

DEPRECATED: decode the key from an appropriately sized byte array.

Note that this form is deprecated in practice; prefer to use ExpandedSigningKey::from_seed.

Panics

This API does not validate expanded signing keys and can potentially panic if keys are malformed or maliciously generated.

To avoid panics, use ExpandedSigningKey::from_seed instead.

pub fn to_expanded(&self) -> ExpandedSigningKeyBytes<P>
where P: MlDsaParams,

👎Deprecated since 0.1.0:

use SigningKey::to_seed instead

DEPRECATED: encode the key in a fixed-size byte array.

Note that this form is deprecated in practice; prefer to use SigningKey::to_seed.