pub struct SigningKey<P: MlDsaParams> { /* private fields */ }Expand description
ML-DSA signing key (i.e. private/secret key).
This type is initialized through a Seed, and can be used to generate ML-DSA signatures.
Implementations
Sourceimpl<P: MlDsaParams> SigningKey<P>
impl<P: MlDsaParams> SigningKey<P>
Sourcepub fn from_seed(xi: &Seed) -> Self
pub fn from_seed(xi: &Seed) -> Self
Deterministically generate a signing key pair from the specified Seed.
This method reflects the ML-DSA.KeyGen_internal algorithm from FIPS 204 (Algorithm 6).
Sourcepub fn as_seed(&self) -> &Seed
pub fn as_seed(&self) -> &Seed
Borrow the Seed value: 32-bytes which can be used to reconstruct the SigningKey.
This value is key material. Please treat it with care.
Sourcepub fn to_seed(&self) -> Seed
pub fn to_seed(&self) -> Seed
Serialize the Seed value: 32-bytes which can be used to reconstruct the SigningKey.
This value is key material. Please treat it with care.