pub trait DynSignatureAlgorithmIdentifier {
// Required method
fn signature_algorithm_identifier(
&self,
) -> Result<AlgorithmIdentifier<Any>, Error>;
}Available on crate features
pkcs8 and alloc only.Expand description
Returns AlgorithmIdentifierOwned associated with the signature system.
Unlike AssociatedAlgorithmIdentifier this is intended to be implemented for public and/or
private keys.
Required Methods
Sourcefn signature_algorithm_identifier(
&self,
) -> Result<AlgorithmIdentifier<Any>, Error>
fn signature_algorithm_identifier( &self, ) -> Result<AlgorithmIdentifier<Any>, Error>
AlgorithmIdentifier for the corresponding signature system.
Errors
Returns errors specific to the concrete type which impls this trait.