pub struct VerifyingKey<P: ParameterSet> { /* private fields */ }Expand description
An ML-DSA verification key.
Implementations
Sourceimpl<P: MlDsaParams> VerifyingKey<P>
impl<P: MlDsaParams> VerifyingKey<P>
Sourcepub fn compute_mu<F: FnOnce(&mut Shake256) -> Result<(), Error>>(
&self,
Mp: F,
ctx: &[u8],
) -> Result<Array<u8, U64>, Error>
pub fn compute_mu<F: FnOnce(&mut Shake256) -> Result<(), Error>>( &self, Mp: F, ctx: &[u8], ) -> Result<Array<u8, U64>, Error>
Sourcepub fn verify_internal(&self, M: &[u8], sigma: &Signature<P>) -> boolwhere
P: MlDsaParams,
pub fn verify_internal(&self, M: &[u8], sigma: &Signature<P>) -> boolwhere
P: MlDsaParams,
Implementation of Algorithm 8: ML-DSA.Verify_internal algorithm from FIPS 204.
It does not include the domain separator that distinguishes between the normal and pre-hashed cases, and it does not separate the context string from the rest of the message.
Sourcepub fn verify_with_context(
&self,
M: &[u8],
ctx: &[u8],
sigma: &Signature<P>,
) -> bool
pub fn verify_with_context( &self, M: &[u8], ctx: &[u8], sigma: &Signature<P>, ) -> bool
Implementation of Algorithm 3: ML-DSA.Verify from FIPS 204.
Sourcepub fn verify_mu(&self, mu: &Array<u8, U64>, sigma: &Signature<P>) -> bool
pub fn verify_mu(&self, mu: &Array<u8, U64>, sigma: &Signature<P>) -> bool
Implementation of Algorithm 3: ML-DSA.Verify from FIPS 204 with a pre-computed μ.
Sourcepub fn encode(&self) -> EncodedVerifyingKey<P>
pub fn encode(&self) -> EncodedVerifyingKey<P>
Encode the key in a fixed-size byte array.
Implementation of Algorithm 22: pkEncode from FIPS 204.
Sourcepub fn decode(enc: &EncodedVerifyingKey<P>) -> Self
pub fn decode(enc: &EncodedVerifyingKey<P>) -> Self
Decode the key from an appropriately sized byte array.
Implementation of Algorithm 23: pkDecode from FIPS 204.